summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsbinding.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsbinding.h')
-rw-r--r--kjsembed/jsbinding.h90
1 files changed, 45 insertions, 45 deletions
diff --git a/kjsembed/jsbinding.h b/kjsembed/jsbinding.h
index 40e2f11e..cd79cdc7 100644
--- a/kjsembed/jsbinding.h
+++ b/kjsembed/jsbinding.h
@@ -22,9 +22,9 @@
#ifndef KJSEMBEDJSBINDING_H
#define KJSEMBEDJSBINDING_H
#include "global.h"
-#include <qstring.h>
-#include <qvariant.h>
-#include <qwidget.h>
+#include <tqstring.h>
+#include <tqvariant.h>
+#include <tqwidget.h>
#include <kjs/interpreter.h>
#include <kjs/object.h>
@@ -38,7 +38,7 @@
*/
namespace KJS {
- inline UString::UString( const QString &d )
+ inline UString::UString( const TQString &d )
{
uint len = d.length();
UChar *dat = new UChar[len];
@@ -46,19 +46,19 @@ namespace KJS {
rep = UString::Rep::create(dat, len);
}
- inline QString UString::qstring() const
+ inline TQString UString::qstring() const
{
- return QString((QChar*) data(), size());
+ return TQString((TQChar*) data(), size());
}
- inline QConstString UString::qconststring() const
+ inline TQConstString UString::qconststring() const
{
- return QConstString((QChar*) data(), size());
+ return TQConstString((TQChar*) data(), size());
}
- inline QString Identifier::qstring() const
+ inline TQString Identifier::qstring() const
{
- return QString((QChar*) data(), size());
+ return TQString((TQChar*) data(), size());
}
}
@@ -71,64 +71,64 @@ namespace KJSEmbed {
KJSEMBED_EXPORT JavaScriptArrayType checkArray( KJS::ExecState *exec, const KJS::Value &val );
- /** Converts a QVariant to the closest possible KJS::Value. */
- KJSEMBED_EXPORT KJS::Value convertToValue( KJS::ExecState *exec, const QVariant &val);
+ /** Converts a TQVariant to the closest possible KJS::Value. */
+ KJSEMBED_EXPORT KJS::Value convertToValue( KJS::ExecState *exec, const TQVariant &val);
- /** Converts a KJS::Value to the closest possible QVariant. */
- KJSEMBED_EXPORT QVariant convertToVariant( KJS::ExecState *exec, const KJS::Value &v );
+ /** Converts a KJS::Value to the closest possible TQVariant. */
+ KJSEMBED_EXPORT TQVariant convertToVariant( KJS::ExecState *exec, const KJS::Value &v );
/** Returns HTML that documents the specified object. */
- KJSEMBED_EXPORT QString dumpObject( KJS::ExecState *exec, KJS::Object &obj );
+ KJSEMBED_EXPORT TQString dumpObject( KJS::ExecState *exec, KJS::Object &obj );
- /** Returns HTML that documents the QObject facilities of the specified object. */
- KJSEMBED_EXPORT QString dumpQObject( KJS::ExecState *exec, KJS::Object &obj );
+ /** Returns HTML that documents the TQObject facilities of the specified object. */
+ KJSEMBED_EXPORT TQString dumpQObject( KJS::ExecState *exec, KJS::Object &obj );
- /** Returns a QStringList that contains all possible properties,
+ /** Returns a TQStringList that contains all possible properties,
* methods and slots for use with a completion object
*/
- KJSEMBED_EXPORT QStringList dumpCompletion( KJS::ExecState *exec, KJS::Object &obj);
-
- KJSEMBED_EXPORT QPen extractQPen(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QFont extractQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QBrush extractQBrush(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QPalette extractQPalette(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QPixmap extractQPixmap( KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QImage extractQImage( KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QString extractQString( KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQStringList dumpCompletion( KJS::ExecState *exec, KJS::Object &obj);
+
+ KJSEMBED_EXPORT TQPen extractQPen(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQFont extractQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQBrush extractQBrush(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQPalette extractQPalette(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQPixmap extractQPixmap( KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQImage extractQImage( KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQString extractQString( KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT int extractInt( KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QColor extractQColor(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QSize extractQSize(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQColor extractQColor(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQSize extractQSize(KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT bool extractBool(KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT double extractDouble(KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT uint extractUInt(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QStringList extractQStringList(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQStringList extractQStringList(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QDateTime extractQDateTime(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QDate extractQDate(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QTime extractQTime(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QRect extractQRect(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QPoint extractQPoint(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQDateTime extractQDateTime(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQDate extractQDate(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQTime extractQTime(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQRect extractQRect(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQPoint extractQPoint(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QFont extractQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QStrList extractQStrList(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQFont extractQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TQStrList extractQStrList(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT QObject *extractQObject( KJS::ExecState *exec, const KJS::List &args, int idx );
- KJSEMBED_EXPORT QWidget *extractQWidget( KJS::ExecState *exec, const KJS::List &args, int idx );
+ KJSEMBED_EXPORT TQObject *extractQObject( KJS::ExecState *exec, const KJS::List &args, int idx );
+ KJSEMBED_EXPORT TQWidget *extractQWidget( KJS::ExecState *exec, const KJS::List &args, int idx );
KJSEMBED_EXPORT JSOpaqueProxy *extractOpaqueProxy( KJS::ExecState *exec, const KJS::List &args, int idx );
// Helpers for Variant conversions....
- KJSEMBED_EXPORT QStrList convertArrayToStrList( KJS::ExecState *exec, const KJS::Value &value);
- KJSEMBED_EXPORT QStringList convertArrayToStringList( KJS::ExecState *exec, const KJS::Value &value);
- KJSEMBED_EXPORT QDateTime convertDateToDateTime(KJS::ExecState *exec, const KJS::Value &value);
- KJSEMBED_EXPORT QValueList<QVariant> convertArrayToList( KJS::ExecState *exec, const KJS::Value &value );
- KJSEMBED_EXPORT QMap<QString, QVariant> convertArrayToMap( KJS::ExecState *exec, const KJS::Value &value );
+ KJSEMBED_EXPORT TQStrList convertArrayToStrList( KJS::ExecState *exec, const KJS::Value &value);
+ KJSEMBED_EXPORT TQStringList convertArrayToStringList( KJS::ExecState *exec, const KJS::Value &value);
+ KJSEMBED_EXPORT TQDateTime convertDateToDateTime(KJS::ExecState *exec, const KJS::Value &value);
+ KJSEMBED_EXPORT TQValueList<TQVariant> convertArrayToList( KJS::ExecState *exec, const KJS::Value &value );
+ KJSEMBED_EXPORT TQMap<TQString, TQVariant> convertArrayToMap( KJS::ExecState *exec, const KJS::Value &value );
/**
* This will throw an exception with the error string.
* @returns An error object.
*/
- KJS::Object throwError( KJS::ExecState *exec, const QString &error, KJS::ErrorType type = KJS::GeneralError );
+ KJS::Object throwError( KJS::ExecState *exec, const TQString &error, KJS::ErrorType type = KJS::GeneralError );
}
#endif // KJSEMBEDJSBINDING_H